@@ -1,7 +1,5 @@
 # Portions Copyright (C) 2010, Manfred Moitzi under a BSD licence
 
-import sys
-import os
 import unittest
 
 import xlrd
@@ -9,6 +7,7 @@ from xlrd.timemachine import UNICODE_LITERAL
 
 from .base import from_this_dir
 
+
 class TestCell(unittest.TestCase):
 
     def setUp(self):
