@@ -1,8 +1,6 @@
 # Portions Copyright (C) 2010, Manfred Moitzi under a BSD licence
 
 from unittest import TestCase
-import os
-import sys
 
 from xlrd import open_workbook
 from xlrd.book import Book
@@ -10,6 +8,7 @@ from xlrd.sheet import Sheet
 
 from .base import from_this_dir
 
+
 class TestWorkbook(TestCase):
 
     sheetnames = ['PROFILEDEF', 'AXISDEF', 'TRAVERSALCHAINAGE',
